// eg. because eg. (shell) - scruss, 2018

// get threads.scad from
//     http://dkprojects.net/openscad-threads/
use <threads.scad>;

sc = 22;
$fa = 6;

/*

shell is approximated by:

1) base - hemisphere;

2) top - Persian architectural dome profile,
         described in:
         “Gereh & Arc” by Sayed Akbar Helli 
         pub. Kashan (Iran) 1986, p.25

*/
module eg(s) {
    union() {
        difference() {
            intersection() {
                //  45°, r = 2
                translate([-1 * s, 0])circle(r = 2 * s, center = true);
                translate([1 * s, 0])circle(r = 2 * s, center = true);
            }
            union() {
                translate([0, -2 * s])square(4 * s, center = true);
                translate([0, 2 * s + sqrt(2) * s])square(4 * s, center = true);
            }
        }
        // 180°, r = 1
        circle(r = s, center = true);
        //  90°, r = 0.5858
        translate([0, s])circle(r = (2 - sqrt(2)) * s, center = true);
    }
}

module eg_half(s) {
    intersection() {
        difference() {
            eg(s);
            offset(r = -2 * s / 9)eg(s);
        }
        translate([2 * s, 0])square(4 * s, center = true);
    }
}

module eg_shell() {
    difference() {
        rotate_extrude()eg_half(sc);
        translate([0, 0, -8])metric_thread(diameter = 36 + 2, pitch = 3, length = 16, leadin = 0, internal = true);
    }
}

difference() {
    union() {
        translate([0, sc + 2, 0])eg_shell();
        translate([0, -2 - sc, 0])rotate([180, 0, 0])eg_shell();
    }
    translate([0, 0, -5 * sc / 2])cube( 5 * sc,center = true);
}
